
.. Use the following to start a new version entry:

   |version|
   ----------------------

   - feature message [author]

1.0.0
-----

- Add a logging filter that allows for ``%(hostname)s`` be be used
  within log lines. [pumazi]
- Logging from a YAML file. [pumazi]
